
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python FinTech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']


def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    pass


class SWIFTParserError:
    """
    SWIFT parser returned an error.
    """
    pass



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x0b\x00\x00\x00@\x00\x00\x00s6\x00\x00\x00y\x08\x00e\x00\x00\x01Wn\x14\x00\x01\x01\x01e\x01\x00d\x00\x00\x83\x01\x00\x82\x01\x00Yn\x01\x00Xe\x00\x00e\x02\x00e\x03\x00d\x01'
        b'\x00d\x02\x00\x83\x04\x00\x01d\x03\x00S)\x04z\x1afintech package not loadeds\xda2\x00\x00PYARMOR\x00\x00\x03\x05\x00\x17\r\r\n\t'
        b'0\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x9a2\x00\x00\x00\x00\x00\x00\xd3\xce\xde\xe2\xefa~\xc89\xb7\xbbVE\xdbn)\x00\x00\x00\x00\x00\x00\x00\x00\xe5\xfc\xe5\xc6c\x91\x87O\x14LJ\xd7\xe9\x1com\xec'
        b'FN\x14\xd9"\x1b%vg\x83\x8c\x92\xd8\xc7\xfdF7\x02K&\x9a\x1e\x8e\x15\xd2G[\x08hW\x08np]\xbf\xfer\xbd\xba,V\x05\x00<\x80\xa6\x8a\xe55\xd0\t\xebb>\xb9\xa8\x88S\x8f3\x13s\x19"'
        b'\xfa\xc4\xb4\xb4\xe5\xd7r\xc7?w-,\xd7\x1d\xf6\xb8\xd6\x9e\xb4!^\xc7M\x89\xd8\xc5\xc9\xe6\x0c\xb8\xe9\x03\xaa\x93.?\xe0\x9e\xda\x8fw;\xe9w\xcc<\x14\xf7e\x1b\x1ae\x10X|\x07\xfe\xb8\xcb8Z2\x14\xe1'
        b'\x89\xb4\xf7\xd3\x139_\xedKmL>9t\x1a;\x9b\xd06\xc5:\x0e\x04\xae\x90\x8fAO\xf4\x08KjV\xb1"\x1ay\xe8\xd2\x7fm\xcf\xc7JQ\x1f\xac\xcaxw6`\xa5\x96\xfc\xd7_c\x0e\x9f\x05\xc7\xdbB'
        b'\xb5\xd2\x1a7\xe5\xdd\x8a\x0b2\x8c\x7f\x9c!\xc6\x95\x01\x16h\x13l\xe2\x83\x06\x99\xca\x82H\xcd\x93\xd8\x9e\xa16\x0ej;O\x18\xe7+\xd1bL*\x84\x88$\x17\xac3\xae@\xa38\xb4\xf8\x9a}\x17\x82_Fk\x9e'
        b"\x8e\xe7\x16K\xab]t*\xda_ \xe9\x95\x0b+\x82\x98\xd1\xe3\xd9\x13\x1c\x14\x94\x90\xf8C\xd5\x05Yo\x16\xbbMa,\xd6\x7f|n\x90\x83'I6\xfa\x07\xd6A\xde\xffi\xb8\xc0\xb29T\x03\xa6\x06\xfeU\xd3\xa4"
        b'\x85\xff\x0b\x1ej\x86\xcb1\x1c\xfc\x84\x05%e3\xbbx\xact\xa4\xb4\xc8\xc9\x9d8\x7f\xc7I\x17\xae\x7f*\x8d8\xaf|\x9af\xd6\x17\xd4c\xae{\x0f\xc5|\xad\xe0\x88c\x85ui=b\x8c\xc8\x7f\xf1\x89\xffz\x00'
        b'\xf8|TN\xf0pa:(h\x9a\xdf\xd3\xf8\xad\xa4+:\x92\xfa.\x11o{\xdcb\xd5b\xdaC\x9a\xa3]V\x83Q\xe1P\xc2\xb1\xff\x90Ju"L\xcf\xa3>\n\xdb\xeeM\xe6\xe4\xd6\xe8S\xb0\xac\x93\x13x\x8d'
        b'\x1a\x85\xb5\xd1\xb6\x80\xa4\x03+l\xdd\xf9F\x15[v%\xb19\x03cC\x9d\x9d\xbe\xf5X\x9d\xbd!]\xe4\xda\xb0 d\xa2z<\xf4w\tQ\x9a\xe8=\xec\xf9\xf9QR\x1d\xff\xa2[)Z\x01\xb6zoa_\x7f'
        b'\x8dl_\xb8(\x10D>\x9d\xe9o\x1c3\x80\xad\x8b`\xa7\xbe\xac\xa7nt\x1b\xceU\x0fF\xdd\x8a?sC\xa4\x8flU\xb0\xe4\x07\x11hl<\xb1l\xc8\x90W\xaaQ\x97>\xf7">-\xf6\x88\x94\xffk\x10\xbb'
        b'\x83\xe88}HT\x13\xf3\xe1]3\xca-\x89n\x14\x89\xd3\xb3R\xc2\x97K\xd2\xc6F\xf5B\xf0\n,\xf8\x1c\t\x1cV2v\x14\xa6[\'$\xaa\xb1:w\xb5\xeb"\xbd:zq\x0b\x0bY\'\xb8=\xb8\x18l\xf0'
        b"y\xe0\x84A\xda\r\xa9\x92\xb8\xf5f\xd3\xdf\xb2\xb8\xc4\xe3\x1f\xffV\x1b\x07\xe07n,v\xfc\xe1\xd8\xb8\xb6\x16\xbb\xec\xb9\xb1\x0f\xc5\xdf\xa0\xd9\xdc\xef'u\xbd\xa2]\xb8\x9ec\xab\xce\xbe7G\xe6h\xfbj\xce\x96\xff"
        b'r\x07\x8el\xdf\xd2\xc7\x89\xa8\xe4[\xe6B\xaf\xf6\xdf\x8c__\xf5\x17\x11\xa4p\xc8"\xd9\x1fN\x16\xdd\xd2\x88\xa3\xdcT\xc7\x13\xc9f\x87n$AU\n+u\xb7\'\'\xc76\xe9\'\x8e\xb5\x88m5d\x87q<'
        b'\x14\x90\xa8\xefU\x05\x8e\x11\xcf\xf2\x8b3\x00(\xf2jf\xc5\xb4C\x04\xbf3\xd6\xc0\xf3VK\x1aJ\xa82\xbd\xe7\x14\xba\xa2CP\x1d\xd8\xcaG\xfd\xb3\x9eK\xb3\xd0o(o\x9cp\xe2\xe7\x84+z\xaa\xfe\x8ao\x1d'
        b'\xa5\xbb\xcdp>\xd9\xa3\xf8W\x93\xa9I\xe1\x92qn\xb6\xdc\xba\x88\xa7[\x04[q\x05\x82|E\x0e\x8c\x1fK\xf4\xa3\x05EDar\xaak\r\xefj\x07\xe6\x14\x06\xe9\xf4`\x11\xb3]n*\xbd\xa4\xf0\xa4\x08\x08\xcc'
        b'\xe4;`\xb4\x190B<q\xdeA\xb9\x85\x0f\xb0oC0\xe9k\xbfE\xbcF\x0c^\xa1\x14!L\xfdu\xbdq\xa2J\xf7\xfe\xfc_\xa7\xf4:\x9ba\xeb\x18\xf3\xecz-M\xb8w@q\r\xc6\x19\xb4\xfe\x8d\x1b\xaa'
        b'j\x92v\xddd\x8b\x1aXs\xf9\x80G\xa0\xbb\x12\x08\xf1$\x11\x15\x087\xc2\xe4\xafYyW\x0f\x98\x01\xdd\xee\xd3\xcb^\xb1{\xfe\xcb\x98\x1b\x9b\xf5\x00\xca\xder\xb2\x9fL:\rg\xe5\xc9h\xfb\xb6+\xa4\x0e\xbb\xf4'
        b'\xd2;2\xc6\xc8S\xa9\xc9\n\xed\xc2\xa5\xb7B\x0b,D\x81k\x88\xa7@\x005\xa7_\x9fW\xe7\x8bL\x8d>L/xI\x81\x94\xf4\xa9\x8bi\x83X/\x9a\xb9\xe1\xc4,\xf2\xcc\xb1U\x9e\x89\xbaXPXidG'
        b'\x90\xc8,\xc5\\\xf0T\x82Q\x05\xd5R&\xe9\x9bf\x9f\xf3w\xd7\xc6\xcd\xdc\x13\xab\xc0n\x17\x8d\x9c\xf0|K\x96\x94t\xb8\x8e;\x8b\xde\xc9\x8a\xd9\xdb\x0e\xa6Yy\xd2\xf4\x19^%\xbc:t\x07\x15\x9b\xef\xeb\xb7e'
        b'\x15\x9f\xba\xfe4DJ\x00\x884Y\x14\xb1\xcb\x19\x18\xf5\xdfQ\xdfe]ZR.\x15\xfe\x17\xeb\x04\x87\x12\x05u;\x83T^*WP\xd9R`\xb4Q\x930\x13\xe3\x8c0\xac\xe3\x96\x98\xc5\xe6m\xcc\xc3f\x96\xe7'
        b"\xb7\xba\x12\xb8@\xeb\x12\xcf\xad/\x80\r\x0f\xf3\xeb\x81\xfd\xd8\xe1xV\xe7\xdb\x85\xff\xe6'.\xc8\x0c\xbf\x0b\xdd9:\x9a3)\xf8\x9a\xa3\xab]\xc0\xab0L7\xfdH\xd6\x1f\xd80\xa9t>\x15ap\xcc{Kd"
        b'%o\x01\rR\x81\x04\xfd\xfb\xfb\x8e\xd0\xcc{l\xd7%\x8b\xc0\x81\x1f\x8b\xa5\xc9\x87\x1f8\x98\x89\x9e\xb3G\xc4I\x94\x96I\x19~\rM\xf0s\x10R\x01\x022/\xe2r|[\x90\xb6\x81\xe6\x18g\xb1\xd9\xb9z\x99'
        b'\xdd\xd8\x12\x07q\x91\xb7O~/\x86\x07vT\xe2\xfa\xcfw\x04\xa3+\xaf=\xd3\xa1:\xc5&\xf2\xc4+yA\n\xb6u\xef\x90\xb3\x19PN\xbb\x1a3\xbb\xeb\xe9\x910G\xcb\x0c\xab\xc5\xb3\xe6?U\xfb\xd3\xbcS+'
        b'\x865\x18\xf2\x83\x1d\x10`a%P\x04\x86I\xb9O\xf3\r\x85,\x9dp*ZzO\x9ba\x88\x8e-qt\xbdC\x05\n\xb8\xefz#\xd0\x10\xb4\x19\xe6q\x04\xc6B\xcb\xd3\xf2\xdf\x86uuf\xee\xaeGf\xa5\x1b'
        b'\x91\x00#\xf4T\xf4>EG\x04\x9d\xbbZa\xc9\xcf\x1c\x9f\xc9\x95U\xe0\xd2x\xb2\x81\xc8{\x7fm#\xaa~\xe8,\x1d\xd6\x82z_\xa6\x8c~z\xff\x17\xcb//\xab\xea3lH\x7fvK\xcd\xf9-\x85]j~'
        b'T\xa2+\xe69\xb87z\xd0\x87\x83r\x94\x81\xf3\xb6\xae\xf0\xcdR\x8f\xa2HC\x12\x895\x89>\xf9U\x9aR\xc3\xd17*\x10\x933\xbbo\xc5u\xd9\xe4\xa6\xf1\xd1\x14\xcaV\x13/I\xec\xd3\xbdl\xf8\x9b\xe0\xdd\x9e'
        b'\x94O_\xed\xf0\x98H%\x82\x84\xc9*\xc5\x1a^\nc\xe9\xcb"\xb2m\x97\x93H\xf7\xcf\xdc\x00x{\x1ek\xca\x15\x7fe\x8d>\xc1\xf6j<\xbf.\xfb\x8a \xdeZ\xca\xde\xa7\xfb#\x9a\xe0\xd4|\xf0\xa4\xbe\xe1"'
        b'6\xe9U\x84\x82\xf6\xd2]\x96\xb4\xaf\xe2(X\x9f\x06f\xda\xbd7\xc7\xc0\xe2#\x8f\xf5\xd6\xac\xaaLr\xda\xc6oc6\x10\xbc\x9f\xa2\xc65\xf6\x12\xe5u\xe3\x950\xef\xc6\x00;\\\x8fu-\xf5\xeb\x08\xd1Jt\xd3'
        b"\xe6=\x0c\xb46\xde\x8f^0\xd5]?\x19\tI*\x1bL\x8dP\x02%\xd3\x06V\xd3\xfe\xb7\xf4\x14=b\xad\x97<(\xbbw@\xeet'\xa7\xeb]\xa8\n\xc1\x1e\x10z4\x99\x87W\x0c\xdc\xa8\xac\xcd\x14*zK"
        b'\xc6\x94\x019H\xf9\n\xd7b\x12%mO\x89\xc0t\x1b\xbf\xb4x\xbc|\x81\x07&-,\xfb\xe7\x15\x99\xb5\n\xa9\x9f+i\x91\x14c\xd1\x8d\x83\x80\xab\x95\x80\xda\xe5\xe5\xa2\x00>r\x05\x97?M9y[Y\x93\x04'
        b'\xac\xa7\r\x89\xa7\xca\xe7\xdc\xf0\x9a"%\\W\xf8c\x16da}\x8a\x19\x98\x81)#\xa8{\xdb%us\xd12a\xa7\xc21\xc1I\x91;p\xbe\xbe\xd6\xcdVY\xf6\xd7Ls\xcd\xa3\xa5\xd8\x9eJ TZ\xc2\xf7'
        b"'qZY\x97\xbaY\x10\x00}\xd7t\xcfhv2\xa7\x8f{$9E\xdf\xaf\xc9\xdal\x9e\x12\x8e\xa4\x94\xf5\xc9\xad\xde.\xe7\n\x8c?\xa5\xa9h\xe1A\xddm\xdbF\x19}\x14\x0f\xd5\\5\xbe\xf0\x0c9\xf7%J"
        b'M\x7f\x9a\x1c\xdfgq4\xeb\x81\x11\x17\xdc@eY\xfe\xd5\xb3\r\xbcR\xd0\xed*\n\x82Y\x00\xce\x01\xccg\xfa\rm\x7f\x04\x19]9\xd8\x1c\xd4\xf1\xfc#\xf1\\\xa4^\xc5\x90l\xb1\xc2\x08\xb1\xd2\xe5\xf45W\xee'
        b'\x94\x89~\x1ey\xb5MI\xef\xed\xde\rP\xc0\xdd\xef\x8c%\xf9).KuG\xca\xef\xbe\x9d\x07\x94\xfa\xdd\xd20|\x0c\xb1\xf6\xfe\xb9\x1c\x86\x9b\x98E\xbcj$\xb2c\xe9\xb7\x9ak\x171\xf33\xcc\x81)\x08\xa7p'
        b'\xae\xc1s\x80Y\x87\xed\xf7\xac\xcc\xc2\x9b\xc0\x1c\xae\x0f\xden\xa5\xf2:\xe4:n\xa5\xea\xd1>E\xbaK\xdb\x11\xb1T\x9ag5\x85^\xdc\x104\xfeH\xb2\xb5J.\xe8\xc5E\x85\xd4x\xbd\x16\xcf%\x1f6\x8a\xef\xad'
        b'h\xc4\xbbK\xcclo\xe4\xd3\x02\xb4K\x1dD9\xf2\xc5\x16\x98\x86\x1a*>y"\x8a%\x80DfE\x0f\xbc\xe8\xa8\xbaK\x03A\xbc/\xa1\xe4\xb2|\x9d\xfe\x7f\x04\xe4?$-\x19F.\xd6&\xce{\xc2\xd8.\x0f'
        b'Z9O\x9e\xb0\xd3<\xb3\xa8\x0efb\xa2B\xfa.\x94\x99\xb5Z\xf1\xcb\x15E\x8a\x0c_#f\x94\r,\xca\x19\xe8l\xb0\xbeP\x89[85\xacU \x90\xd9|\xbfhIQ\xe3z\x1a\xd2XhtC?4\x00'
        b"\xbe\xdc\xcda\xf6,\xc2\x9c8\xf0\x00\x00\x17\x8b\x95\x82\x83\xa05\xef\xce\xb0\xcdXu\x15\xf0@\x9d2\x8b\x1c@H\x8f\xd8\xdaR2\xfc.\xb4\xa1\xb5\x8f\xa1\x87\xc3\x8e\xc3\xe0\xf9\xab\xe5\xde#'\x90\x1c\x9e3\x87\x87}"
        b'\x8f\xc1\x93\xad\x1aA\xa7\x8c\xb8\x81j\xca\xe6J\x7fe\xc4\xb5i,\xaad\xae\xa37\xd4\xd8\xc1\x87\xd6\x8b\xce\xf0p?\xd2\x92`M\x15n\x8e\xc2#\x95]j\xa6\xe6\x90\xd3T*\x7fx\xf8\xeaR.C\x02h\x83\xe0'
        b'\x84\xa2\x02^:=\xbe7 \x87*c\xa6\x8c\x08\xf5\xf4x\x11\r~\x9d6_\x06q$\xcd,\x8e\xe3.%\xc2\xcf\x86\xdd\xcf8f\xdaE\xdaz\t\xda\xe7\xc0c21\xa9+\xcf\xfa\xbe^\x02\xf1\x01\xe2\x00\x103'
        b'\x07\xc5h\x1a\x1f\x06\xdb\xcaj\xfb\xdf\x8d\xaa\xfa\x07\xf31\xbf\xd7\xda\x95\xfc\x08\x06\xf7\x9d:\xb3\xe4cc\x9d+QnEE\x93\xd5[\x8eP\xec\x8c\xaf\x9c\x83+\x03\x89N\xe91\xc1\xbdHR\xcbS\x08\xd4\xa5\xd39'
        b'\xf4\xb3\x13R\x02\xe3N\xf1\x06cK\xe3\x06\xf9-\xc5\x11dE\xb3}\x11J\x909\xe2~\xc9\xb8\x06\xed\x87\x91=\xaf-\x03b\x82d/1\xd4\xdd\x8c\x00\x7f\xbd%\xf2\xbe\xf0\x1f@\xaa`\xd5\x83\x17\x0e\x85\xecB\xf8'
        b'\x15\xf7D\xefT\x0b\x97o:art\xf8\x18\x01\x13\xa5\xdco\xd51T\xc1\x17Ey@r\xd8=\xa0\xc2}\xf3\xf2\x10\x12\xfb$\x1f\xc0c\x07c2\xceL\xc9\xc1\x1a\xe3|\xf7Y\xb2\xf5M\xcb\xfb\xacn\xf8>\xf9'
        b'XXW\x13\xbe,\xa8\x01\xda\xba\x00\x89\x04\xe8\x1f\x95Y\x92\xbb\x0b\x0cX\x01T\xf2o;(\xe3\x91\t\x01\xee\r\xb7\x18\xb1\x89\x8e\xbc:\xffX\xed\xd6\x92\xa9H\xdcK3\x14\xe9S\xa1\x01\x83=\r\xef\xd5W@A'
        b'd\x1d\xe5Q\xe5\xc3t\x94\x11\x12\xd4!\xb5F\x15\x1b\x8bkFV\xf9\x15P.pll\xe8\xeek`\xe1$\xceP\xcf\x0fL\x01\x1c\x8e\\\xe9\xc19F,!\xdf{,\xf3\xce\xb5@5M\xca&\xa6\xe0\x822\xd9'
        b'\x8b$v\x91$E\xb5\x0c\x84\xf4\xe5\xcc\x0b \xf9\xa1"\x90\xfd\x0cn\x84\xa2A\xd2\xb0\x1c\'\xd0\x9aO\x96\xea\xe5\xe3\x04/\xde\xc4\xa6\xedRb\n\'{S\x1a\x19\xcd\xa8\xa6Z\xea_B\x8bbT\xdf;\th\x81'
        b'T\x87\xdaG\x19\x8eM\xf4\xa1\x90&~b"\xe3\xc3\xf9\xcaV\xa2BT\xdb\xd7;\xd4U\x17/\xc6v0\xc9u-\x95\xf0\xeb`\x8d\xa3\xa9\xee,\xb9\xc92\x92"\xe2\'\x7fq\xb7\xfc\xdfh\x9f\xcdr:-\xd3\x90'
        b'\xc5\x03\x08\x08\xe5\xe1\x80\x07q\xf6\xff\x04o\xcaNZh\x83Q\r\nSz\x8c\x1b\x16+0{1Q\xa4I\x18H\x9e2t,\x1ak\x07\xa2m\xa6\x84\xbfT\xab\xe6\xb8S\x93\xea\xb2f&\xe3\xb9\xad\x9dez\x99'
        b'\xab\x15ko\xe9\xae\x1b\xc0f\xd8DDUP\x02\xa2\x06\xeb\x97%\x1aS\xdfxn\x96[\xe6\xf0~w\x18=\x9d?W\xf0\xdaM\xae\nGz1L\x011_\x7f\xce\xfc\xb8\xe0\x17_\t\x14_\x0e\xeaH\xda\x0b\xe4'
        b"\xb9-\xe4*\xf1\x9c\xa39\x92\xf5/\xa3\xb4\x1ctr\x01\xe2\xf2a\xcao\x81\x97\xad\xdbF\x03\x86~V\t\x92H6}O\xd5\x03f\xa9\x01\xe7\xf2B\xb52\x10'\xe0\xf2d\xe6\x97\x80q\xf2a\xe5l\xbc\x96\xed\x0b"
        b'\xdd$\xed\xeb\x86\\\x7f\x80l\x11\xce\t\x9aV\xc65\xa1\xb2\x9c(\x003=\x11\x07gm\x9b\xee\x14\x15\xce8\x817\x1d\x1a\xbdiW\x94C_\x8c2zj\xc9\x18qe\x8d`z\xda\x8f\x838^?\xfb\xfer\xb7'
        b'\x96\x0b\x12\t\xe4`2\x12\xe6P\xeb;\xfc\x19G)\x1a\x1e\xf8r\xc0\xe16+_\xd3\xae0\\+\x95\xdb\x96F\xb0\xf5\xf8\x19\x98\xe8C\x116Q\x14_\xf6.\xf6\xcd\xa5^siD\x8f\x84\xa4\xa2l\xc4\xc5\tv'
        b'\x12w\\\xb1\xbd\xc0\x88Pdrp\xb4\x03\xe4\xbb\xeb,\xec\xe0\xd1DB\xaa\x8e:\x0b\t\xa1x\xb8\xa9\x0e\xf4\xe5\xf6#\xa6x\xde\xeb\x95\rJ\xa8\xd2\xdd\xe3-\x18\xce\x0e`\x1c\xf58\xeb\x86\x9f\xea\x16\xab\xd9\xaf\xca'
        b'\xbf\xfb\xee\xa9F\nkN\xf1Y\xc0F\xb3+\xe9\x82\xfd\x96p,I+\xe3\xae\xe7\x7f\x83Z\x1a\xd3\xae\x83\xc7<]\xc4\xc8m\x04r\xc2\xd1\xc6O\xaf\xaekd\x9c\x12\xbd\x06{\x80\x86\t\x8at\xf3z\x85\xaa:w'
        b'\xff]\xfd\xddf\xa0\x12\n\xed\x80\xec\x10)\xe0f{\xb1>p-3KH\x80V\xad5p-\xec(\x80:^H\x00\xc9+\x00\xb1\\yx\xff )8i/\xaaGvX\xc3\xcfk\xd9\x8d\xca0\xedCZ\xcd'
        b"\x07\xa4A\xb6\xce\xf5\x8627G\xd2AC\xe4\xfe\x10l\x07\xc8v\xde.,9\xb7\xcb\x86\xee\xab3\xdb\x1f.\x99y(\x83\xbb\x92[\x9c\x93\x00\x0b\x8f\xba\xeamt-\x8e'/\xf1\xce\x06\x9a\x91+]\xa1\xd1\xf5\xea"
        b'GyhG\x05t\xf3\xc8*\x1a\xfcdvq\xde\x9a\xc6.\xa5\xf9\xf8\x18\xd0\x18M\xfbU\x0c@\xcd|\x0c\x1a\xa3U\xd1]\xb3\xd2o\xb7\xd5\x17\x06\x84d\x7fL\xa6\xe7}\xa8\x06\xf1W\xc9\xc5\x80Y\xc6\xec\x06nT'
        b'\xa6\xd9\x11M\xbba<-/\x90\xa8P\xa0:\xf7\xab\xddz\xa9m\xb8\xa0\xb7\xa2\xce\xabD\x86\x1a\x08\xb3dJ0o\x870\xe9\x9d\xb74\xf5xw6\xd3g\xd1\xc7\x1c\xc9/3r\xc1\x9a\xd2\xfe\x84\xc5\xc2\xf3\xbdt'
        b'X\xb0PN\x943\xde~\x9b\\S\x8ec\x1f\x11-\xe2\xd2\xc0q\xbb,\xf0\xd4\xd9\x0e\x96\x96iN\x9b(\xcd,\xa9\xaa\x90\x17\x13\xe9B\x9bV\xb27\xd6\xb5\xf2UV\x07\x00\x07 \x96\x92\xfb\xd7J\x89\x14H\xc2\x9e'
        b'\xc7u&RK\x19\xd7)s\xd0\xf3Xl4\xeb&pRTN\xcf\x9d\xdf\xa6\xb1\xe7@\xc5\'"u\xc7\xf4\xbc\x9f\x06\xe8\x9cw\xda\xbf\n\xee\xe4\xbfa\xb873\xd8\x86\x9a\xbd\xbfRp9>\xa4\xd8r\xb2\xa0\x04'
        b'\x0ek$\x9f\xac-[y\xf6\xcc\xf1\xab&&<\xd8\xf1o;q}\xdc\xa2c7\x91\xfe\x0e75U\x1bt\xdb\xdcEE\xa0\xe5\x9c\xa5\x8a\xb1\x18\xe4_s\xde\x9d\x88\xc8.2\xeb\xe7\x15\xa2\xaf\xf9l&\x9cV\xbd'
        b"&\x8f\xb9\x9a\r\xfa\x08\x13\x19\xa5q\x1eg\xce\x95G\x8f\x18y'\x8a\x13\x04\x11\x16N\xcf~9\xa0\xb5\xff\x1a?\xac\x99\xe4\xf8\x84d\xe4\x80\x03\xea`\x9b\x1d\r\x1a\x7f-gy\xca\x012\xf5\x88f\xbf\x1f\xe5\xb3*"
        b'\x9a\x14f\xc1\x17\xd8\xb6\xbf/\xb9D\xc4\x17\\\xbf\xde\xc86\x82\xee\xdfL\x80J\x10\x9a\x86N\x93\x9d\x98x\xe4\x80\xa1\xa3\xb4\x81\x15d\xb3\xb4W\x0fy6>5JPi\xb0\xf8v\xd1\xdbB\n\xec\x1f\xfe\xcd\xd4W'
        b'~6\xe0\xea\x1bi\xcb\xcb%a\xc3\xb9\x8f\xf8\xcc|\x11\x91\x80\x12\xc1\xfe\xaa\x89\x87\x1b\x18\x8d3&5&\xc5-\xe7\xa0h\x04e\x9c\tm<.\xe9\xee\xe9Z%.\x0f\x9f\xc0\x81\x84\x9c\x8c\xea\xadT\xb5\x06ag'
        b'\xb3\x07\x1d\xafW\t\x8fe\xb5\xe6.#\x1fU\x8e\xccX^\x84\x96\xe0\xe2fN\x0e\x8br\x8fSw\x90z\xd9%\xdaG\xebH9\xde\xfc\xf0P\xe5\x1c\xccW\xb7\x81p\xe6\xf3(\xee\xe6\x13o\x8e\x1b\xc2\xebgT|'
        b'\x80\x1d\xde\xf4\xdd\x06e\xa7\x01\xa0\xa9vu\xabG\xc4k\xa3\x1e\xb7\xa1\xbe\xee\xaf\x84U\xcc\x17\xe8\x13\xe2\x1e\xb7`8{i\xe3378\xe3\xa6\xba\xc5g\x02\xd4*\xbc\x81\xb2w\xf8\x9c\xc8 \xc7\xfb\xf8\x0cp\x97\xb4'
        b'vkS\x03\xb9\x05\xb4\xde?\x14\xa9\x0b\xd1\xf0\xd1o\xcaPD\x19 ) \x93^\xd4\xc1\x86[d\x14NV\x1d\xe4\xa1|\xe2\xaa\xf4\xc0v\x89\xde\x10\x04\x7f\xe8\xa7\xd2\xe9`#?\x1f\xa0\x9bk\xa6\x13x\xb2\xd9\x98'
        b'+\x98\xce\x94f\x1e\xc9\x91\xe5\x00!\xa91\xb6G\x96O\x18\x99W\x16\xb6\x1e\xb5\xa9\x7f\xc4\x15\x12\xf8$\xf5}\x8f\xf4\xe5\r\x9d\xbc\xa8/\xfd\xf4\xa9j\x83y7\x02\xc3l{\xd2\xb9N\xc2\x80q9:M,\xe42'
        b'1\xee\xb7\x1a\x0f\xdb\xff\x85\x87\x15?#\x0c\xea^5~!R\xbb \x85`i\x0e\xadx\x85\x0f\x1050\x7fE\xe0%\x08\xbb\xe6 E\xc5u\x98\xb9\x113\xbfj\xf8\x04\x99\xde->\xfb\x11\x0e\x9a\x94#o\x11\x82'
        b'\x98\xd0\x1d\x15\xed\xe1\x9e\xf1 \xf4W\x08\x98`\x1a\xde%\xb2\x19\xc6s\xce)%r\xf4\xbfg\xc6?\xb2*}\xef\xb4\x84\x9c\xb4\xec\xd9\xe9\xae+!KzG\x8f\xb6\t\x15\xc9\xbd\xb6\xce\x8b\x95\xc1K9\x08\x05gQ'
        b'O\xd7\x8cZ\xd1)\n\xf1\xc6\t\xc4\x06\xc0\x1a\xb6\x8e\x18o\xafr{\xd6\xbe\xdae\xab\xefLc\x18\xca\xd6\xb8w\x98!\xc0F\xf3\xc7\x9f\xacsJ\xacBj\xfdM\x00\xfcw\x96!\n\x13\xa49\xdc\xb7\x94\xa5\x8dt'
        b'7.\xc4\x01%mT\x0e*\x88p\xe5\xa0\xce\xe3\x9d\x90{\xd8X\x0cm\xd5\xd9_\xcb\xd1\x1d\x01\xf9\xae\xa8\x95\x90;\xeem<O1\n\xd0\x83\xdc\x14\xbf6\x08)O\xf7\x9dXvMt\xa0xpR\xfcu\x9d\xbc'
        b'AD1\x95.\xb63\xc6N\xb6\xe6\x16\x95\xa1\x89\xc0\x07\x8f\x90\x7f\xc0,\xe0\xa3 a\x9dG^\xd3\x99\x95O\xc8\xa3\xa2\xae\xf7\x8e\x1fj\x04\x83\x93\xbdc\xf1\xcaL\xe0\xa17\xb8:v\xe9\xb5\x02=J\x03N\xc1\xb9'
        b'\r\xf4\xec\xe7!\xbb\xb7i\xa4n\xcc\x9b\xe5z`\xado\x9a\xb6:\x931]\xfb~\x14\xb4\x18\xe6\x1d\x8d=\x91\xb1\x01\x8a\xbbF\xd2\x9ek)\xec\xa4\x0f\x1ez\x84t\xbf\x87\x02\xa8\xbd\x1a\x80O1 \xab\xfei\x83"'
        b'd]W}\x17\xd7\xb6\xaa\xe94\xb7\xa1\x1d\x9a\xc6\xff\x07\x80\xbb\x8d\xfdx\xb5d\x95\xe1\x10\x88\xd37\x9d\xc4\x0c[\x84#\xf0%\xf2\x10\xee\x1eoj\r3\x88\xbf%\xd4\xa7\xc5\x19\xe1\xc2Xt\xbapW!\x13{\x86'
        b'\xf46\xad\x8f\x9b\xbaF\x97e\x8b@\x81\xc9b~dh\x97}\x9cp\x0c\xfe\xf0\x1d\x11\ryL\x18\x8f\xb2\xa1\xd1\x8d\x1dl\xf3\x07)K\x83\xf4\x93_\x17\xc5\xb7\xd1)(3[3\xb2\x97\x0e.\x98\xdd\x16rQ\xac'
        b'\xd1e\xdd\x98\x1fq\xf3\x12\xb0\xdd\x9c\n/\xd7\x969\x84\x81\xc6\xa7Z\xb6\xc3X\x18\xd8Nx:(\xa8\xc6\xf8\xc0\xe3T\x0e/\xe7|R4;\xd8\xd2\x0e\x82\x93\x0b\xed\xbf\xe6\xfd\x9ex\x0b\xf2\x1d\x18\x0eYy\xc9l'
        b'\xd3\x10O\xe8\xd7\xdd\x10\x13\x07\xff\xb4\x9dc\xf4Q\xc7\xf6\xda$\xec\xf2\x12\x92m<w\xf31\x8d\xb4\x80%\xa05u\xf8\x84bdXv\xe2\xc7\xc3A\x8c;\xe0s\xb1y\x97r\x96o<\xb2\xc4\x17]eP\xce"'
        b'\xb8\x99\xdd2\xc6C\xbbc\xac\xab\xfe\x8b\xb4\xea\xf4w6{\xbes\x97\x82]\x9e\x80V\x90|\x8f\x97:F-\xa8\x8d\xafO\xd8\xfb\xfe\xdf\x9c\x890\x85\xfb\xe1\x95\x86\x1f\xbc\xef\xf8\xee\xa5*\x14\xe0\xd0\xbf\xfd\xd4\xafD'
        b'\x8d\xf1\xeb\x00\x88v\xf3\xbb@\xafw\xb6\x86\x9b)\xe3n\xca-\xdfI\x93\xa1A\xff\x14\xbb\xea\t\xa8\x06{l\x83)\x90\x14N\x90\xde\xe5H\x8c\xfcp\xbe\xf9\xd7k\xf6\xe9\xee#\x80A\x02\xf2\xe1\xa4\xff\x99#\x1a\xe1'
        b'\xd0\x88\x13\xb4\xa3\xfe\xe0\x08\x90\x9c\x9ca,9\x8f\x85\x85%\xeb\xc1>\x82i\x8e\xa7\x1b!\xa3\xda\x9a\xca\xb7\xcdt\xa9\x08\x14\x05u\xa6<\x03JT\x97$m\xe7\xbf?\xf7q.\xd3C\xde\x17H\xfcC\xc9\x14\xb1\x8a'
        b'[\x96\x0f\xae\xd8B"\xb7\x0ca\x9e\xbd\xaaey\xb6\xd3\xce\xb6)d\xc4\x14c\xb2\xef\xe7)=u\xe81\xd0\x9c\x15\xf1k\xad\xa3\x9c[W\x01\x96{e\x89\xa4\xf1\x80\xef\xb4\x84\xb9\x14*\x80c\xef/#\xbb1\x8e'
        b'\xc4\'_\xeb\x9c\xa0\x03\x98\x1e\x8b6\xb1\xa6\xf8\x8cP\x00as\xed\xe7\x18P\x98[\xf7\xf5\xa7\xcf\x04\xc8\x19\xc3\xc5\xba\xa9\x15\x9dk\x10\xcd{\x13k\xc3[\xc8\x95\x83,e\x8c0\xbb/\xe2\x8cy\xd1t\x9f"6W'
        b'(\xf4L\x06W\xbcCO\xd4\xbe\xf0d\n\x07\xbeQ\xeb\xfe\xe9\x81\xa3\t\xec\x0evM\xf7\x8f/\x1e2<\x96\xcd\x96{\xab\x1e\xd5}\x91C\x7f\x91\x98\x1a\xa5\xa2\x13\x06\xd1$D\x0e\xdb.\x97\xfeO\xc7\x0b@x\xea'
        b'z[\xaf\x91m\x98DJ\x84\xe1\x9ai\xabX\x05\xd4,\x90\x0b\xcd\x82W\x85\x8aH\xbbG\x01O[\xb58\xe8\x1c\xd0\x0b\xbb\xc7v\x9e\xd8\x07\xb7Z\xf0\xfce\xe5>Q\xd8[\x1c\xc6\xde3\xf96"\xd7R\xbc g'
        b'\xa3\xcf=\x08\\\x8aTV\x01jyizP\x87\xbdP \x93)\xc8"x!\xe3\x9f\x97S\n\xbb\xad\xf7[\xec\xa9[\x81\xf0\xe8\x84\xa1\xf5\xf7\xcb\xb2\xe9\x85\xee\xd9L\xe5]\xa7{\xb7\x1eY\xacs\xe1\xc1\x07\x9a\x0b'
        b'I\xbe\xe6\xe9@\xf6\x16\xa05\xc2:\xbf\x0b^\xb8\x01\x98\xe9s\x18\x87\xc9pfd\xef\x11\x90\x85\xb0\xf4z%\x99\x0b\xa96\xbd\x8f)\xb0\x96\xc2*T\x0e\x9e\xe9\xf7\x0e\x8en:\x80\x81\xef\xff~~qu&\xc8\xb8'
        b'\x82}pL7\xa2\xad\x8c\xdf\xfc<\xcb\xba\xa3\xb8\x9a\x96\xc6\xdakTH\xd4[d\xd4\x84\x8f|\xf3\xac\xbb\x1b\xec\xf9\x9e {\xb9\xd2,\x0f\xd74\x91"\xba=\xb0iGR!\x19\x81\xa3\x8f\x8d\xb3\xa88\x95\xe7;'
        b'\xa4\x87_\x06\x0f\xe0\n\x10\xe8L\xa6\x9elxV\xfc\xd7\x1f\x07\xda\x1d\x87\x98J\x8e1x1}\xbe[GAp52v\x94\xe7\xb5\x9e\xd0\x0eB\n\xf2i\xb8,\xe2\x9c\x83\x12Q1\xc1\x1e\x98\xe92~\xa7<('
        b'/^\xb2;\xce\x8c#\x0fA\x86(\x99\x06\xc2N\xf1so\x00\xa6r\xbe\xc4\xc1nEK\x02_\xc2\xa7X{\xfd\xfb\xce\xdf\xcf\xa0\x1b\xd4{\xc1e\x8c\xe8\xf0J\xe6\x85\xc1\xcc\x99d\xb7\x9fz\x08(\xf3&O0<'
        b'c\xb6\xd7\xc2Y*\xad>\xd6\xf5wc\xde+u\x82\xfd\xe9\xc2\x92\x93\x91\xc1\xc5\xc66\xb4\xa3H\x95TL\x83\x92\xe2X\x0bo\x17x\xc2q\x15\xe7\x90\x82\xf1\x06\xab7\xa0\xba\xde\xd8\x1b_5\xd0%\xaaA\xbe]\xbd'
        b'\x0cn\x87\xcc\xcb\x84\x160\xe6\xd5\xe7\xc1\x11 \xb7\xc9\xb0k\xd1t=J\x8b\x90\xa1(H\x08\x13\xc0e\xb4\x1c>\x93M\xba\x9f|;8\t\xa8\x12^\x88\xd4B37a\xd0[\xd2\xcf\xf3\x89\x80cn&!\xf5m'
        b'\xbb\xb2\xf6O\xf1\xe8\xba\x84Z\xa3\xa7\x83\x14N{^\x1f\x9c\xec>\x15B\xabF\xc5\xc7R\xed\xc3\xaf\x88\xc0\xc9\xe0\x1a\xbc\xeaq"\x1f%\x14\xbc\'\x898\x1b(H\xd6\xe0\xa8\r\xdeG\x83\x9e\xe2+\x1aV\x14\x8a\xff'
        b'\xb77\xd8\xcf\xeedN\xaa@)\x88\xba|\xc0\x90\xb1\x07\xd2t\x035\xd6*7b3)/%!\xed"\x1c\xec\x15=\xf1E/X\xdb\x12\xdb\xe9\xf2\xe0F)33\x02X\xf0\xc6\xfe\t\xa2\xce\xb5\xe0\xe3\xd7ug'
        b'c\xd3\x11\xb0kA\x8a\x9a ,Y(\xd5\xb8\x87\x8c\x15\xac\x847\x8b\x13sa\x86\x85m\x9f\xf6\x88\xc4XQ]E\xf9$\x8a\xc2\xcd\x9f\x12T\xee\x076\x87\x8c\x9e\xa0\xb7\xd1M@\xd4T9\xb8;4\xda\xfe%5'
        b'\xde\xcd\xe2m!\xe2:\xa2@F@!,v\xa1\x15rbO=\xbb}\xb2bpw\xa6V&\x9f\xfc\x12\xde\x93\x9a\xc6c\xc7\xfb\xb6\x03?\x0b\xf6A\xb9\x0b6\x98\xff\x16\xc2>\xcc\x9e\xa0\xee\x93Y&\xc4.\xaaS'
        b'\xd6\xb5J\xebt\x05!\x97\xb8}\x8f\xe4\x8a\x1dz\x12y\xa5 \xaa\xd6ZE\x0c\xc9v_xV\xeb\xd6\xd3\xbd{\xec;H;\xb6\x8b\x02\x80\xc0W\x96\x14\xcbj!(\xbdY\x12&\x03V\n\xb6\xf1\x13\x00\xca\xado'
        b'\xebH\xe4tz\x06\x97t\xe0\xcfS\xcak{=\x9d\x7fX\xd0|s\xc2\xef"\xdd;:\xbcj\xe3Jq\xf6A\xad\x89\xd7\x13\x1739\xa2\x0f\xb1\xa6 \xc0V5Z\xe7T\xc0NJ\xeb"}"\xc0\x91?Bj'
        b'\xbc\x83A\xda_\xce\xa0`\x99g\x85BIa\xa5\xb9\xafJ\x8f\xa6\x12\xe2\x9d\x13\x04\xa0\x18\xad\xf2H\xe9\xf0t\x05l\x00U\xb9\xc7\thf\x10FP\xd2\xf4\x0b\x86\xe2\xbb\x12w\x9a\xb0Z\xe8\x14\xc5\x14\xce\x0e\xdc\xd1'
        b'\xa2!\'o\x180\xa0\xa8zbn\xb5\xb0\x7f\x1a9\x18J\xedv\xab#\x8fY\xacg\x88\xe2\x91\x11q\n\x04w\x1elz\x8c\x8ao\x91\xf6\xb0\xf9\x12\xca:\xf0\xb5\xf0\x1c*qq\x8aH"\xb8\xf1J\x08\xaa\xb7\x7f'
        b'\xa7k|\xef\xd3ai@\xd4\x1d{\xcb\xf5\xc0\x86\xfc\xdd\xce\xf5\xdb\x13J\x90\xf1\x19\x0c\x0f\xf5P\x00@H\x8c\x05\xbc\xc1\xac\xfc\xc3\xb4\x97\x18\x1b\xc7\x00\xf1RT\x15g[\x19\xad\x8b\xf7vN\xf7\x19\xe5q\xf7\x90b'
        b'\x8a\xd0or\x83\x06M\x0c\xc5C/\x8b\xde\xd50\xa7\n\xbd\xe8u\x11R2\xe4\xfab{\xa7J\x82\xbe2\xb3\xb4\x03$\x0e\x92\x81\xcd\x05\xce}\xab"h\xa6pb\x10<\x98L\xe3\x06CD\x8e8\x87g\xed\xf0\x92'
        b'D\x90w\x0b\xbe5\x1f<\x08\xdfM\x17\x0e\x17Yw\xa9X}:\x10K\x1e\x87\xc4.\xe8\x1bC\x81\xf0\xd9\xe0\x08\x15\xc0p\x1bA#x\x92w\xd3\x9e\x9f\xb0\xceA\x038?\x04\xce\xfeukz\xda\xd6\x17\xf8{\xda'
        b'P\xb6h[\x1dM\xbbd\xdd\xc1Kb\xb0\xd9P\x14\x15G)\x01[b5\x0cq\xb5\xb4\x8egw\xcbp\xdd_l\x14\xa1\xbaG\xc5\x18\xe8u\xb7rU\x10\xb2Ih/0\x08\x11tc\xf4\xce\x7f\r8|\xc06'
        b'c\x8d\x98\x9f\xec\n8\x19uU\xc8p=-\xa6\xb6\x03\xfd\xfa\x16\xf6V\xa1\xe5\x87\xaf\\8\r\x89\xa1\x95\xa8M$N,\xcd\x8e9\x05.\xb4\x99\x8a~k<\x97\x7f\xe5O\xec&\xf9X_1\xf7\xbcy\xd7B\xf4'
        b'X\x0b\xcdtn\x9av\xcb|\x94<S\xfcq\xb6ONU\x00|\xde)\xf73\x9e\xa3\xf1\xc5)\xc8\xbd>\x98\x07\xcd\x02\xe8\xbd\xd4\xa7\x1ftI\x97p\x14\xea\xf8\xf9\x8e4_\x07\xa2\xa49\xad\x88`\xce\x88\xf01L'
        b'XG\n#\x18[A\x90\xe7\x8670\xd9%\xb3\x962\x8d\xd3\xfe\xe3\x03ts\xd8QIoh\xb8\xfb\xd1\x16z0\x05h\x01T\xc5+\xc7>f\xe1I\nJ|\x9a\xaf3\x92{\xb9@\xa5\xb2E\xd2\xf8P\x19c'
        b"\xa7`\xd6\x10\x08'\x86u\xac\x1aW\x8d\xbf\x88\xfc\xa8\xde#\x9c\x82\xaf\xcd\x8f2@6\xa8+\xd8\x0f\xa2\x1f\x99)V~\xbf\xb4\x17\xceY0\x0e\xb5\xd6Y\x9b\x8bfS\x95~\x1d7\x7f\xbf'\xf3\x91\xfa\xf2\xfc\xccB"
        b"\xc1Zd\xdc\xb8u\x86\xe3xF}_I\x05B4\xc4\x1d\x96\x99.\xae\xe5\xf4\xdd\x9cM9\xfd\x0f\x82N\xe9'\xce_\xa9\xec\xba\xce~\x04(4\xa8J/\xf9V\xec\x165\xd8#tN\xc0\xd5**`U\xc5\xe0"
        b'\t\x9b.\xb6AW\xbb^fXP\xc0\xc9WR\xf53\xae\xac\xaa[\xe9z\x9b\x04\x05\xac\x86\xf5\xf0*\x83;Q\xb5f%R\x07\x9d\x86\x06A\xffrhZ\x86\x85\x1eQ3s\x11\xf4T\xda\xd8 t\x8al\xcfF'
        b'\x1cm\xb2z\xbe],\xec\xd7\x1eX\x0bA\xd2\xac\xcd\x15PW\xf8\x96\xc9\xa0\xcf\xa6p\xb5\xf2\x19Zv\xb0\xb4\x01a\x9e\x18rh\xe4\x16\xf6n\xf4\x91*\x10\x9b\x1f\x9c\r\xcd\xd9c\x00\x7fLB\x12\x15a\xa6\x10\x0b'
        b'\xbb-\x92\xfd{\x89\xffW9x!o\xbd\xd4x"\x01y\xe9\x98R`\x11\r\x19\xbf\xec\xe8\x16R\xf9:\x93\x0f\x80\xef\xe2k\xfb\xee\xf0\xcd\xea\xf2]\x8c!\xf0\xca,\xf7\x89z\xd9\x05P\xd1:\xad\x03\x080cM'
        b' \xa6\x02H\x0f#\xe7\xcc\x9b\xe8\xf4\x83\xb3\xadUl\xba\r\xdc\xe4*\x05\xeb)\x17\xfc\x1b\x9d\xccRIX\xe8\xa0\xf0yn:\xfa+xF:4\x92\xd8\xbf\xd7\xfb\x0e\x91\xfb\xd7\x00\x9fZ\xf8\xbe\xe1\x0b\x9d\x1a\xf0\x02'
        b'\xc9Qz\x18\x8e\x1f\xcc\x03XDC\x9fS\xe4_\x8bq\xd6\xaa.\xb4\x19T\xf3\xd4S|U\xa3\x07\xae\xf6\x89\xd7!\xd1H\x9btQC\xc5\x01\xfdL\x90\xddV\x10Z\xb1\xf9`e\xc6,\xad\x05\xa8\x01#\x898\xaf'
        b'W\x1a_\xa1\xbc$\xecsh\x83\xea\xe6\xf5\x8a"\x9d+"!\xe4Tr%6\x0cb\x8cS\xd6\xbd\x1c\xac\x0f:i\xe1\\\xad\x00\xa7\xc5\xf7\xf8f\xd0\xf5\x0fP\x12\x16]\xa9\xa3\xf1\x1f\xc0\x82l\xfe5\xb2:Zp'
        b'\xb5\x96\xcc\xee8\xcb\xcc\xf9\x9d\xe3\xf3\x8fV\xcc\xba{>\xd2J,\x9a\x9a\xa8\xc1\x0f\xa1\xdc\xdb9\xc7\x1a\xc0\xa5l~;!E\x9e\xf9\xe1\xefY\x0c\\\xf3\xbc`z\xc29\xdc\xdc\xb3\xfa\x10\xc5\xa2\x9e,\xfd\xc2S\x8f'
        b'dy\x08}\xb3\xee!\xdd\xc0\x91\xb1oL\xa0\xa0\xde\x18^\x11S\xf4\xf4\xb6\xc1;\xe4"!.\xd4\xe6\x06\x8ev\xa1\x80\xfa\xf9\\\x92w8c\xfd)M\x84\x01\x01X5\xe2\xed\xc7\xcd+,p\x8e\xacw\xab}\xac'
        b'\x92?\xee\x16\x7f\xad1RQQ* \xdel\xed}\x8f\x9eE\xd7\xb3\xba\xa8\xaf\xb38^y\n&\xac\xa9V\xf2\x14\x19K\xe3\xfb\xc0\xe9\xfe\x9aQ\xf1y`\xdd\xba\x89\xb9U+\xc3\xaahh\x1f\x80^\xaf[\xfd7'
        b'x\xe4\xdc\x8d\x1c\x82\xe5\xee\xd3\xa8\xb7t\xa6|\xbcm\x1eHW47O\x1d7\x02\x9d\xcew\x0f\xa6\x9c\x1e\xdb\x9e\x12\xcd\x1es\xec\x9c\xfd\x9bo|\x03\xf3\x9b\xd8\xacCRgpZ\xa5\xa66\xda{n\xf9-\xcdD'
        b'\xda\xd8\x9f\x7f\x08\x185x\x8clgs\x9a=@yh\x0e[\x8eY$\x17\xb9^\x91\xd4b\x06%\xa1\xf6\x01\xdfa\xdf\x05\xe5gC@w\xf2\x87\xb3\x1d\xc5h\x86\xc3\x1bG(\xa1f@!n\xeb\xf5\xa5\xabr~'
        b"\xcd\x04:\n\xd1\xeeh\xec\x99aTI\x91S\xa7{\x18wy-)\xc2$\x19E\xdd\x8cL\xb9$\x9e\xc0\xe1\xf6\x17\xba\xf2!\x99\x01\xc3\x92h\xa4\x8a\xe4'$*\xdb(f\xbf\x9b\x8fB\x14u\x93\xcc\x12\x10$\xa9"
        b'\x82\xfc\x0e\xd8h\xcf\xb8j1\xd7y\x83\xc9MxY\x97\xde\x8d\xcc\xc9=\x01\x88\x8d\xc8v\xae:5\xd1\xa2\xa0\x0e@$\xd3#\xc6\x80[B\xceUg\xf0\xee\xc2\xd3\xdfc\x10\xa28\xbdmQ\x15\xf2.T\xb3WC'
        b'\x118\xfe\x92}\xe6\xc5\xdaxR\x15\x1b\xf4R\xbb\x87\x82*\xcb\xc1E\x87P\xb8\xde\\\x14$\xef\x0e\x9e\xa2\x9b6\xb0\xb3\xbdC\x11\xfc\xf5z\xfb\xa5\xdd\xea\xb7\xc2r\x864\xf2[\xa5\x18\xde3?\x10.:\xf6\xd9\x98'
        b'9\xcc\xc5f\xa0\xec>\xaeO\x0c\x9d\xf2\x81*\xa4JcT\x1e\xe40q2\x86\xb6\xb3n\xbb\xfa\x99\x88j:\x08\x9aS\x03\xad\xb0\xcb\xf9i\xf2\x16\xde\xfe$\x1fQeed\x8ff\x00\xfb\x1b\xe4\x18\xb3\xd1\xd6\x0b\x98'
        b'}\xc1\x06\x175}\xa9g\xe2;\xc5d\xff\x92\xef!e\xb0\'{\xed\xe7\xb5\x8d\xad\xe6Tr\x8a\x14\xaf+\x05\xbdxk\xa9%\xd9S\x18\xc7\xfd\x83\xcf\xf4r"\xb1\xf0\xad\n\x97\x84\xbc%\xa0U+\x1d\x0cG\xf5\xe3'
        b"\x88\x13\xaf<\xe1,\x14g\xec\xd8\x06H\xbcJ\xfas\xfc\x11t\xed\xdbK\x10\xdfU$\xa6\x90V\x0f\xc1/'\x7fqf\xd6\x98\x08?3\xe1[\x1b\xa4V\xdc\xa8\xfd\xd6\xab\x07\xb0X\x0b\\\xae\x82\xc7\xa8\x80+N\x07"
        b'*\xc6G\x98D+\xae\xda\xb8Xg$\x1d\xaahcy\xa7\x99/w\xe3\t\xd9j\x88\xba`<\xda\xc2\x07\xdf\x94\xa3\xbd\x03\x85\xd6\xdc\x9e\xd44Y\xdb\xb8N\xf2(\xe4\x00\x03)\xf8M\xad*\x06\ri\x06\xebD\xbb'
        b'\xad\xd1\x06\xe9)\xdf\xd4\xda\xb0\x133\xd7E92\x8b\xe2\xe9{\xeb7\'\x06\xc6\xf1\x10IjWv\xfe\xf3d\x0e"\x04|\xd6\x92\x93\xdcT^\xd5\xc0\xb8\x96s\xeb\x8b>\xd5\xd2.\x1e\xec\x10\xf9H]\xb79\xaf\xfe'
        b'x\rxs\xe5\xa0\xcf\x0cN\x14B\x00\xe8m\x89L}\xbd\xbba\x97\x81\t\x88\xf4\x8f\xbc\x1b*|\xc5m\x11\x80BT7\xf9p\xa0N\x11\xee\x9f\xdb\x1d/\xcd\xe4\xd4\xb6z\x1aG\xc9\x06\xc0G!\xfeN4\x04\xb1'
        b'\xbc\xd9\xe2\xfc1\xef\xb2\x10^\xc3\xdcc\xe4\xee\xa7\xaeY?0\xf5\x89\x0fx\x9d\xdb_EZ\x89!,\x1b\x04\xdc\x1a\x89\xecy\xa5\x93\x08\x02\x02\xe2T\xd4\xff>\xb1\xa48\x97\x01\xbfR\xcd\x041\xae\xb6\xb6\xf3t\x9d'
        b"\xb7\x13\xe4\x13W\x9d\x82T\xdb\xef\xc6C\xf4Dn\xc2\xb9`\xf4R$0\xc3\xfaDJD\xa6\x17\xb4\xe7p\xcd'\xfd\x91\xd5\xab\xc6,\x00#fd\xbe\x15gp\xdd\x1b\xbd\xff)O\xc1\x81b\xe7\xc5M\xa7\xd5\x7f|"
        b'\x81\xb7+o\xbd57\x95Q\x1b\x97j\xf4i\xcb\xd46,\x05\xfc\x0b\xb0\xf4\xecRZ\xfaj(\xb1U\xf8vj\xdd\x1a\x93\x83\xfaI\x9c\x02\xbe\x91\x97\xfb{\xeb%\xdb\x9d6N\xa3\xbd\xbb4e\xfd\x17\xefj\xff0'
        b"\xceh\xe1\x9f\xfco\xd0\xe7\x85\x9c[g\xa2U\xf8b6\xc0IZu\xefr\x11\xdbl\xab1'\xc1\x16\xa5\xb5\x17\x1a\x15Q\x95\xf3\x94\x1cQ\xf6\xcf\xfe\xbfXG\xf1\x88j\x8a\xc6#F\x15\x04M\xc0\x9dI\xf5\xab\x8a"
        b"$\x90=\xdb6k|\xc9\xbb\xfa\xe2\xe1y\x83\xa0ws'4\xa3\xe2\xbd}\xea\xc9C0n\xc6\x1bL\xa1\x1d\xb7:\xb3\x8c\xf8+\x10\xa6\x93\x88.\x8e;ZM>5\xe6\x9e\xfc\xa5\xfeK~\xe0\x13\xf4\xf5\xec\x0f\x8d"
        b'\x83/\xe5\x8e\x91\xb1X\r\x8f\x90\xc1Q\x8f\x00\xfe\x0b\xad\xfa\x99\xb9\xdb\n+z\xdd3\xffY3\x95\xc6\xd8\xabL\xf4\xe2\xb5\xa6N\xad\xa2\x91sT\xe9\x1fYS%\xe3\x99\xae\xbd\x85\x99R\xa1-|b\xb4\xb4B<'
        b"&\xf0\xc5]\xf89\xc0W\xf1M\xd5H\xd3p1'd\xcb\xd4\xa9i\x8c\x84C\xcf_E\xad\xb7Q\x1cF\xa0\xbc\x87\x94\x87\xc9)\x15\xc7\xbd\x90\x85\x03\x84\xe4*\xa6\xc6\xfd\x97\xbaV\xcf\x89\x1a\xc1*\x81e\x1fc\x8e"
        b'\xb8\x88\\ \xd8\xfee\xbf\x88f\xc6s\xd6M\xaf\x10\xd3%\x17VY\xa1\xba\x93\xbaha\xbbT\xf1\xea\x94\xf8I\xc2;\r&\x06\x01\xefG\x89\x9f\xcc\x82\xe5\x9eZ\xc9\xfd\x93\x9d\xae\xb5\xd6\xb5%-\x82\xfd\xc0_\xcf'
        b'\xd0\x99y\n\xa2\xae\xc4\x84\xa2\xf9\x1a\xd8\x80\xae\xc0\xa3\xd3,\xff\x88E\x0eF+\xb8\xac\xd6\xeb\xa9\n\x0b",\xa2\x98\xfcv\x9d\xbf\x8f,\x80\'h\xc5\x98\x167}\xceDZ\x14\x93[u\x95\x01\xaag\x81C\xc1\x90'
        b'H\xb1\xc3\x93\xfa\xa9yU|*\x14\x86<\nl\xed^\x03\t\x18M\xbf\xd9\xa9C\xb4\x85&J\xdeW\xe2\x1d\xe5/\xe8\x17\xf8\xa1I\xaa\x13dt}\xda\xa5J\x18;\xc7/\xd2:\x1e\xaa\x92%\xce4\xba\x83\xbd`'
        b'\xae}E\xc3U\xf3\xae\xa6\xdb;\x17\x8c\xc2\x87\xd1\xd9)\x0f\x95Q\xc0Z!bA\x99;\xb8\x19x\x9b37\x8f\x16\x9ef~6W\xea\xdb%\xcfJd\x90\x00\xc0\xa0J\x14\xcfK\x900\xba*te\xe4\xf1>\x19'
        b'\xd4q\x84.\xa2\xa3\x9a\xf0&\x06b%e4&Y\xb2N\xc7\xadE\x9e\x0c\xed\xda\x89\xb2\xc4y\rT$`\xb3\x11\xdd\x94\xa6(\x8c\x80_IGy\xa3(\x90\xed%]\x04\xb1.\x0f\x98\x12Vu\\H\x9b\xb6\x03'
        b'\x1d\xdf\xbe\xbb\x9b`\xc4E\x96_\x13\xf4\xf4\x88\xc3\xf0\r\xc8\xf5\x85\xdc\xd5\xbb0x\xee$\x12:C\xda5\xd0\xac\xb0>\x02o7\x98\x81\xb2\xf6\xb3.\\\x18>\x17\x93F\xbb\xa7H*m\x82\x0e\xe9\xbd\xc6\x89-N'
        b"\x84\x839B\x9e\xdc|r\xa4\x12_\x9ez\xb9\xf5U{\xa5\x06\xdf\x84\x19\xc6k\x9e\xec\x81\xe8,\xd6TF\x0coU\x83\x89\x10\xaa\x01\x95\xe2]\xede\x12\xe1\xfa\x88\x0ft\xdbV\x84\xc6\xc7'\xfdO\xf5\xe9\x99\xc8\xcf"
        b'\x04\xe7j\xa8\x92y\x86\x98\x16\x94\xcb\xba\xd72C7s\x84\xf0\x08\r\xc9\x95\xcfX\xbd\xd3S\\+\xd4\xc4[\x84\x89\xdc\xc0\xa0\xdc\xc0h\x91\r\xbf\x97tC_\x87\x85\xe3\x1b\x9b\xf4\x1e\xd3R\xb6\xec\xc3\xc0\x912\xeb'
        b'\xd4\x81\xd1\xc1\xfco\x9d\x00TE\xbd\xa4Z&"S1\xc0\xce(\xf7X\xfd:Y5)\xba/\xd5B\x94\xa2;\xcfo|\xff(N\xc4\x07u\x02\xdfr\xe1=\x12\x9bx\x011\xc8\x8b+Se\xbd\xc5P\xb8|O'
        b'\x93\xf4+\xbc<\x8cY\xb8\x9e\x82~)\xc2a;j\x0f\xaf\xd6%\xfaC\x81x\xc5|\xba\x00Cn\x96\x16f ]\xa7N5\xbf\xe2lr\xb3\xb0w+\xb2\xe5Rs\xebL\xb5\x89\x8c\xce\xf1\xec\xfb\xcb\xecq\x92\xeb'
        b'#\xf02\x05v\x1c\xd5S-\xd2XTb\x12\xefCI\xfa\x83D\xb6\x8b\xe7\x97\xd1\x0f\x91\x85QF=\xeb\x1c\x08\x82/\xd5D\x9e\x13\xcd;\xbeG\x87\xf0\xdc\xfd\x91\x12\x12R\x85\xd1\xb0\x02\x13\xa9\x1d\x87\xc2\x0cn\xed'
        b'\x99KI\x8e\xc3r\xc7M\xc2\x8d\x04\x7f\xca\xbc\n\x01#,\xc8Z\xcez\x18c\xfd\xb0\x9f\xec\x98\xda2OD\xbb\x8dxm\x8e\x0f1<u\xec6Ep\x1d\x87\xd6\x00\xc7\x0f\x05\x83\xf6@y\xb2(-\xacq\xcc@'
        b'b\xcf\x11\xb5I\x81F\xfb\xa0x\x83\xc8\xa0~O\x96\xb4W8A\xdd\x9e?\xb8\xf9b\xdfa\x15\xf9\x80c\xbb\x8c\xb6\xeb\xcd;|\x93\xff\xcdJ"\x13A\xabw\xa4@\xc5a\x07\xeb\xc7X\xde\x8c\xf5f:\xa3j\xf6'
        b"\x98\xe9\xd3\xdb\x12\x01\tr\x95\x13*\x8f\xba\x12\x8b6\x05\xe3\x0c\x80\xe4\x8c\xf5(\x9b|p\xdc|\xb9\x8d\x1d\x9eT9p[\xba\xf5\x05\xe6\x1d\xe9A\x8c\x05JU\xa5OC\xc2wN'\xbb\xa7FK\x9ba\x0e\x8a;"
        b"I\xcf\xee\xd6\xa0k\xd6\xd1\x01[2Y\xfc\x13\xba\x05\xe1o\x8d/6[\xff@\x9ci\xed\xc3UfQK\x8a\xf1\xad'\xbet\x100K\x8c\xa1F\x93\xd7<)\x8f.\xff\x16\xf1\xdclcO<\xab\x1b\x10\x9a\xbf\xe7"
        b'\x95\xb3\x81\xd0\xd6F\xb0F\x922XNh+\x9f\xfa\xafJI\x83\xb0\xe5\xf7\xa6kjx_L\xd9a\x96\xfc\\\x88\x8c\x9c\x16o\xa0\xa5\x8d\x0c\xccz_\x7f\\:\x837\x90\x89\xaf\t\x92\xf9\xdbEH\x03>\x1ai'
        b'\xb3&]YL\xd4\xd6\xb6\xa0\x05+\x83\xd0\xcd\x02\xeb\xfe\xa4\xdd\x02\x07\xa2\x0b\xa8\r\t\x00\xe2\xa7\x00P`\xcf\xad\x9a\x8d*\xca\xb3\x05\xdf\x13&\x08\xa1^\xd4\x8b~.1a\xc1xQ8\xe5\xaey\xfc\x9a\x17\x1b\xcd'
        b'\x96K\xf1\x88\x1c\xeb\x0ci9=\xf7*[2\x07\x83*\xa2-\xcb\x85\xef\xdf\xb1\xe4gO\xa5ePM\x88|2\xecSb\x19\x13X\xd4tv;y4\x84\xaa\n\xb0\xfcfI\xde\xf8aI\xf3\x1f\x1c\x8f]\xf2\x06'
        b'g\xdc\x87\xecX\x1cd\xbdO\xea\xb4t\xb8\xe7z\x90\x10\xde\x05Y\x89L\x80\xd3\x8d\x14\xe8%M6\xf3\xbf\xf4Cp\xdc\x03\xa0\xb6\x03\xa4\x06\xa8\xe5\xd3\x8a\x8d\xc0)9\xd3\xaf\xc3^\xcf\xfe\xd2\xa4\xb0sB\xb7\xcc,'
        b'\r0\x01\xc2\x0e\xfcF\x8a\xf7\xf8e\xc1\xb9=\x8e6\xd9W\xd3.,]\x1c\xf1\xcf\xe4\xf9\x93\x01`yq\xd4\xec\xccj\xa6PF~\xa3\t\xe7\xd4`\x18\\xxM\x01\x14\xb3\xa7\xc1\xa2\xafh|\xd5\x81IvD'
        b'\x82TM\xc2\x15\xcc\xb4R\x9f7\xdd%\x1akE\xc5\x02\x06\xb6\x9d\xad\xc1\xf5}3\xde\xc1\x8d\x1a\x8d\x07\x1ei\x87\xae\xd7\x14\xbb\xcc\xde\xd6\x87\x85\xec\xc5\xafJk:AO\x9a\x8c\xa7sU1\x8aw\x87A\x9f\x8d\x1b'
        b"\xcbWw\x91w\xaf\xb6\x81\xd1\x0f:>\xbf\xbdP\x9f\xf1\x9a\x9c\xff\xd1o:\x17\x8c\x9b\x82H\x8d\xc2y\xc6\xb4\t-\t\x9c{\xaa\xd0\x9e\xe0'4t\xde\x8a\xdc\xe6\x90As~l{ud\x9fD\xef\x05\xde\x1eU"
        b"\xb2v\xec\x1a\x94'\x0e{\x0c\xf5\xd3\xc1-\x03\x16\x7f\x12\xf1v\xa0\x17\xa9U\xe9\xff\xfa\xff\xd9\xc9%\xf1\x07O\xd2\x15}n\xafH\x99\x8f%\xe4\xf9\x14Z!e\xa4\xc5%4\xff\xaay\x04\x05W@\x03\x1b\xf7\xce/"
        b'\x95X:\x88\xaf14\xd1\xc9RK\xd4\x99yr\x962\xf6w\xf0\xc0E\xfa\xfavC\xf2%\xd7/ 8+"\xadL\xcf\xf4\xf7z\xce\xca\x9d\x97\xb6< \xcf\xcbB\x88\x94;\\\xe7\x98\xc5Wca\xe2\xcc\x8e\x1f'
        b'\x04\x06t\x81N\x06\xa3\xd2\xdb\xfa1\x11y/CR\x15\xa4\xd6\xf0!=\xca\xb3:\xca\x03\xa8\xe1Uw\xba2|i\n\xb7\xea<\xa2\x86bi\xa0\xce\x16y\xa4\xbe\xfc\xd6e\x06\xc1\xb7Co=\x8e\x00C\xc9\xb2\xfc'
        b'\xd7Gb\x9b\xd7\xdd>\x00\xdb\xaaN\x8b\x8f&\xa4\xd1\x0bKg!\xa2\x87\x92D\xc55\x1bF\xfa\x83\xdf\x91i:\xed\xdf\x03eAU\x91Aj!8[\x02\xb3\x06\xca\x1d\xac;X/F\xf1\x92\xe5\xd7j\xc9\xef4'
        b"3\xf0'l\xe3\x97_\xe7\xce\x8c\x0b\t\x8c\x10\x8f\xd6@1\x82\xa4f\x00B6\x95\xbcw2d\xf6\xfcRf1\x03\xc58\xae\xff\xfa\xe2\xf6\xa9\xa5\xab\x98K3Zq\x80\xb2\x81bB2F]\r\xd7\xd5\xf3X\xd0"
        b'\xc0X\xf7\x85\xe0\xd1\xf6#,\x85X\x8d\x15\x1e\x90\xd5t\xa6^\xb4\x11i\xf8\xa5u"\x08\x81\xaeH\xe2\xd3\xa5\x10[\r\x89\x94\xa4\xfd\xfc\xb6\x1f\xe8\xc4\xcdN\xf1\xbf\xc3\x1c.\xa9\xd0\x94u\xf8wnBOw\xc8\xac'
        b'j%\xa6\xa7\xa7\xe4\x87\x1a\x906\x0f\x82r}(\x02\xb37\xb3#\x05\xbf\x85R\xec\xed>4\x88\xe7U\x87\xbaw\xc7wK\xcf\xf3?\x88\xfc\x8b\x88*E%~TZ$%e\x90\x0b!\x16\xc1\x0b\x9d\xcf%\t\xeb'
        b'\x83\x15\x8b\xd5d\x99\xb84\xf6{3\xb8\x13\x0e\xb4\xdd\xf5\xf3\xca\xd0#\xf3M\xfe:\x89\x15\xcb\x03\xb3Z\xed\xa8\xb9\xe5\x03\xf1k6>n^\x9a\t.<\xc8\xf5\\\x17\x83\x0c\xa2\xb2\xd5\xc5e7\xe4\xf7=t\xf3r'
        b' 3\xa8\xc8gj\xbc\x9f\x15\xc3\xc4c\x1f\xa2\x05\xfb\xd3\xae\xdd\x94Y\x96ex\x1f\xa4)\x1d\x0b\xd1H\x02\xff7\x9b16#\xe9\xc4\x85M<?C\xaf\x1b/`W\xd0\x0f\x17\xe79\x1a\x88{\x95+\xa5)\xdd\xcf'
        b'\xed=6]\xee\xfd\xb0%Us\x80\xaf\xe3*\x12\xcd#\x93\xb9\xae F\xa5\x17\xb6\xbc\xec\xd9\x9f=\xb2Z\xab\nmn\x93\x12\t\xab\x815G[\xe0\xe61\xa7\xf8\xd5\x12\x0e\xbd\x0f\x0c\x91\xcb}\x8c\xb8\xbd\x1eD4'
        b'\xd5\xb9\xdb\xe4U\xe2?\xcd~\xe5\xa8\x1a\xf8\xdc]9AI\x08\xd6\x16\xc9\x1b\xb1UJe\x11\n\xc6a\xd0\xeb\xea\xd1K\x99\xeb\x1d\xbb \xf1\xb2U\x80wxI\x1f\xb7\xdb\xdf\xc6\xbf%\xbe\xb4\xf9\x8b\xb3\xcc\x15d\xd1'
        b')\xfb[\x8c\x82\x84+\xd5\xad\x0b\xf1\xcd\x16(\xdb\xe8\xed\xec\x10\xc7^E\xe8\x1c((\xb2l\xb9\x03\\\xa1\x9c\xba5\x92\x83\x01\xdaF\xdc%\x16\xaa4\x9e\x9a\xa7\xfb\xf0\xbe\x9c\xa2\x8c\xd9u.\x93\xac\x9b\xfa\xc5xK'
        b"F!\xde\xdc\x82\xaf\t\xc0a?t*9]\xdb\xc7\xac\x13\xd1\xc6\xcd\xb8\xbfM\x84&IZ|\xd1\xd1\x89\x9a\xed\xb4\xcaI\xac\x01)P\x85|\x0c\xbf\xda\xe4\xd7^\xe3\x82'|\n\x94\x84\x91\xb0\xb1\x15\x1bQj_"
        b"TJ\xd9w\xd6\x92\xcaS`\xbe\xdd\xd0\xe66\xf7\xaa\x12}\xec~\x8cM\xfcPx\xacL.\x05\x0f\xd2&\xbe\xbd\xf5\x94\x12\x943\xbc-\x08'\x1b\xd3E\x0bz\x07\xa2u]\xf0} X\xa2t3\xd27\xd2\xdb\x96"
        b'\xd4\xd6{*\x973\\d}\xef\xd3~\xe4\xdb\xbc\xf9h\x91Q\xa1^tZ\xa2\xafh\x9c\x9d\x96\x7f\x14\x1f\x06\xfa.\x90\xcdO\x9c\x8a\x03)\xf6\x8a\x8d\xaecB\x19\xc10+\xc0|\x97\xf4D\x94?`\xbc\xb1\x864'
        b'\x03\xd6\x89?=w\x98\xb5\xf3\xbfW\xcaD\xd3\xe2\xd9/\x98\x93Hi\x16~\xb7\xbbl\x15\x07q\x9aN\x94P\xee\x96R\x8a4\x90@~1\x85\xae\xdc:\xa3\xb6B\x9e4\xcc\xf8}\xf7\x80}{\x9dE\x80_\xd2\xc0'
        b'\xe7\x1b\xda\xac\xa4\xec\xcc\xa4\x82\x98\xbc\x89(kr\xa7N)\x1c\x073\xba\xe8\xad\xb7\xba\x98G4\xaba{6\xd7\xaf\x15Z\xa5\xa8[3\x86\xcc<\xeeQ\xa70\x1e\xd0\xf97\x14I\x10\x9c\x1c\x83\x1a?(\xea\xa6\x91'
        b'~\x19F\xf7\x96\x9e{B8gF\xa3\xe3\x7f\xa6\xce\x86\x84L\x03\xc1\n\xc9\x0c\x19\xe8\xf4\x8d\xf7\xef\x8d\x8d\xe7\x85\x92\x17\xe9F\xefo\xb0\x00\xf1g1\xee\xa8\x04W\x01\x01\x02K\x850\x81\x8b\x80\xa9\x8c\xcf\xde\xad)'
        b'\xad\x0ccy\x0e\xe8\xc5\x8av\x00\xadW\x88PT\xea\x89\x87\xf7\x15\xcbn\xe5\xad:\xbb\xd1}\xf1\xa6B\x81\xfcpH\xacF\xef\xa6\x18\xc1\xa1\xb8`)\xef\xa9\xe0}\x93\xb3\xc53,\x95\x12-\xecCX)+4p'
        b'\xf09\t\xb9\x01\xa5b\xc2\x04\xcc\x13\xf4\xea\xdeO\x17R\xc3E\x1c\xf9\xf7\x1f\xc0\x89\xf0\xfb\xad\xab_\xa5\xce\xab\x15\xd9G\x9e\xa0B\xe5ir\xb3\xbf\x17\xae\x17\x1f\x10\x1f\xf8\xffb\x84\xa6C\xe2\x9f\x82a\xec\xd1\x0bI'
        b'\xcd\xc1\x05\xf7\x87(\xf6\xaf\x99H]\x11\xbe\x15\x18W\xd8\xa2\xe0\xbb\x97v\xd5\xf8\xa8\\W \xb2N\xb4\xb6\xde\xc1F\x10\x0c8\xa85\xe3\xf2D\xe9\x90\x96h\x9b\x183\xdbS\x93\x99\x00\xf8y\xb4\xe5\xba+\xf5\x88\xfc'
        b'\xe7#o6\xe8\xf4\xfdL,0w\x9c\r&&fUt2\xc1X=r\x9b\xebA\xdb8^\x9a92\x83\xa2K(W\xfdN\xf1\xb4\xb70\xb0V)\xa2\xb5\x9a\xaf\xfe\xf8\xfd\xb9\xbb\xdf\x14\xact\x82\x0e\xf7T5'
        b'\xc3\x8b\xabF\xef7\xe2\xfcoR\xa7/\xa0\xf4\x8a\xf9;\xa4\xb7\x07\x07A\xd8\xc8\xdc\x91NE{\xba6\xfb\x98\xf6:<f\xdd \nY\xe7``t\xe9\xda\x04N9\x04\xd5\xe9I\xfe\xa8\x80nG\xf3RX\xe8F'
        b'\xd9\xe2\xa2\x9d\xb6\xe2\xc4\xde\x13v\x0f2\\\xc0:U\x81\xa8o\x9f\xca\xe3\xcal\xb4\xdf\xa0\x18\xff"n;T,\x87\xff\xb7\xbb\xc1;!\xa3\xea\x05\xaf\xaa\xa4\xeb\xf4\x94@\x9fHYH\xbb\x07\xedw\x0e\r\x837\xb4'
        b"X\xa7#\x0fg'74\xcfh\xf2)C\xff4\xc2\x898\xca\x11[\x95\xb6\xb2\xe0!\xadc\xf0\x12Fo\xab\xb1#\xf2\x02\xce\x80\x9a~\\y\n\xaa\x1d\x83\x06\xa3'e@\xa3\x06hA\xb5h\xf0\xfd\x93\xee\x8c\x8b"
        b'\xbc\xa6\x1a\x12\xc0\x11\xf4\xf2b\xbe\xf8\xde>\xff/D/V\xe1\xfe.\x10s\x90\x8d\x1b\xcd,q\xc1\xe4\xd7g\x18\xe2\xeb\xb2\xf5L\xe6\xa1\xc3\x17\xb6$_Vm\xee\xeb\xff-\x11\x1f?\xbf\xfeZ\x05\xfd\xb0\x04\xcb\xfb'
        b'\xd0\xba"\xfe\xba\x86u\xb4\x9b\xd3\x9e\x159\xeeD\r\xe7\x81\xb2\xbf\xbd\xce\x95|!\xbc\xbaV\xa1ma\xff\xb9\xb0\x0bJl(E#oJ3\x13k\x14\xea\xf3\x98\x07\xb1f,\x00\xbb\x134\xcc\x95B\xb6\xb7s\x98'
        b'|\x97"\x83\xcaD\x7f\x84\'\xadP^\xc7mX\x15\x04\x90\xcfK\xb6\xfb\xcb\x01\xc6_\xadb\xf77\xd3U;\xd6\xbb\xe20\xe7\xf7mE\xf4 \xc4\x992H:\xff\x11\xb7\x95s\xbd\x00L\x8e\t\xc4\x8a\xd5\x1c\xa8\xd2'
        b'X\x0e6\xc9\xad\r)\n\xe5%S\xb4\x9c[\xbcM\x19<(<^\x9e~\xc8=(l\xf9\xf7h{\xe9n<\xa9\xad\xde\xb7\xc5Gk\x02\xd9+_\x82_\xa5\xf1|\xf7\x0fo*\xdbU\x9826/E\x14\x1e\x81'
        b'\x05\xbfD\xd3\xf9\x11W+\x00\t\x1d\x04\xfb4\xddk&a\x8fS\xf5\x8a\x01\x87Q\x9b\x0b\x0c+\xe6\x1dR y\xaf#\x1f\xf9g\xeb\xc8Q[\x12\xe6\xa4\xdd\x9c\xeb\x04B\xf9\xce\xb4"\xbf\xa7?5\x7f\x19%\x87T'
        b'\x04\x00\x90\xca\x84\x7f<\xc5\xe1C\xd66\x02\xef\x89N\x91mC5\x83\x8f\x83\x11:QU\xaaD/yL\xd9\xa0\x17K]\xc5L\xb9\xd9W\x1aF\xa1J\x953\xd6\xcb\x94\xdbs\x01*+\xfaG\xef\xe9\x07\x03\x90\r'
        b'\xbd\x1c\xc9\x80Qb\xda\xf7\xa4\xc6Q\xc0@4\x053HB>\x81M\xc3\xb9\xf7\x8fi\t\x945\x86\xe1M\xf9\x04K\x01V\x9ex!\xed\xdf\xa2\xca1\x97\xcb_\x8eNs$\x10o*DS\xff\xa9f7\xe9\xd8H'
        b'\xf2\x07,j\xefS5e\x9d\xbf<\x13\xb0\xdf\x14\xd6\x1d+\xcd$\xe8\x8d\xd3\xb4\xc0\x1a\x82\xc2,\xa7\xea\x8dp3\xcdS\xf9\xa0\xfa\x8d\x02-\xf7\xe9\xd4"\xf9\x14X2\xb3\xee=\t\x1c{o\xcab\xe9\x0b\x17\xa5\xca'
        b"\xcbSj~\xcb;\xb0+\xb4\xd5>\xe9\xd8Z5\xb9;R\xb7\xb85\x13\x91\xcb2z\xbf3`\x94\xb2-[ (\xda\xe3\x1a[\x95z\x8e\xcb\x1e\x85\xb0\xe1\x10\xf5|\xfda:q#\x99\x82\xf9\x02C'\xaf\t\xd4"
        b'R\xa4\xbd\xd1X\xc8\xd0\x87\xf8\xdb\xd5\xe6\xfefx\x9d\xba\xc0\xb0\xf6*\xf6\xcd\x13<\xd2\xce\x1e\xf5\x12b\x12\xea\xbe\x0c\x03\xb1\xa0\xe7\xc4S\xf4a\xc5i\xd3$\x91}\x94h1O3\x1a\x97\xcd\x18\xda/\xcf\xab:+'
        b'\xb4\x1eF\xb0\xbd\x12\\\x9aR\xf4[xD\x15\x82\x8b\xea\x9f\x9b\xc7\x16\xb5\xad\xae\xce\xd8\x87L\x80 x\xe1\x0b\\\xcc\xb3\xf3\x16\xa8WVf"\xf9\x14\x16\x18\x85\xd2\x1b\x18\xa8\xfc[\\\x16i+\x00hE\x9f2\x87'
        b'&)\x1aU\x8a<!\x8a\xee{\x16\tu\xa7n\x92x\x8d3[\x91\xe9\x0e\xfc\x1c\xedH\xae\xfc\xdb\xf8\xf1\xccs\x8f\x8a\x94\x90e\xcb\xd2g\x16I\xfc\x8cm\x9f\xaf\xb6N\x8bI\xf5M\xbc\x03\x07\xf9\x1e\x06@w\x9b'
        b'd6\x1c\x87\xec\xa4\xf4\xdfJ7\xbf\x17\xdc*yc\xbb\xff\'\x06\x03\xd9\'}\xa2\x8b\xa3\xd3\x0b\xac\x95\xb9\x12\xf3M\x84\xa3\xc9\xae\xe2\xf15D\xb1"\x15\x01\x9a{\xf2\xf7c~\x9f\xc4\xab=\xcdz\xf08\x9b\x16\x1b'
        b'\xa2[\x94\x88\x1a\x00\x1b\x94;i\x03d|\x1bg\xb2\x8e\xae\xd9\xd5\xd4\x9b\xbd(\r\xcb\xa8<.#\xe5J+w{%s\x0f\xb5\x16gz\xf8\xe7\x92>\xdf""\xd4\xed\xe2I\x9a\x12{\x12\xb3\xe5q"\xae6\x12'
        b'\xc4\xca}\xcc\xb9j\xc2v\x92\xfe\xf4\xf65\xc4U\x86\xdbD\xa5/\x839\xb7{oB\xff\xb1E\x019\x9ep\xb0\xd3.\x00\xcb\x08z7\xf7\xa1U\xda\x88\x0c\xf6=\xadFB\xfdE\xdaL\xd8\xb3\x95RP\xd3\xd0\x8f'
        b'\xec \xaf\xa7\xac\x994\x1d\xecu4#H\x97\xf0;\xd0E\xfc\x9f\x81\xc2\x96S#\x9b\xf5\xac:\xe2K_\xc7W\xd7-\x96d\x8ax\xb1\xa8\xdf\xdc\xd1\xb5`\xa1=\xea\x1b\x19v\xfd\xd5S\xbd\xa7s\x08\xcf{\x11\x16'
        b'# \x91\x0fj\xa6\xfa\xac\x139\x01\x07\x9f\xc7:0\xe0z,\x95\x90\xe0\x83\\\xefq\x05\x04\xea\x89\xa6\x0f\x97\xe0h%\x8a\xb8\xa8;@+\x9e04\xad\r\xc1\x93\xd4\x92\xed\xa6\xab\xc6\xda\xac#WC\x97f\xd1u'
        b'\x19\xec\xf0\x83\x88!\xcf\x1ak\xb2oh}\x98lG\xd6CnQ#s\x9a\xb7\x89\xa4\x90\x95j\xd7\xb5\xad\x00\x0f\xf58\xbc\x16\xc3\xe4\xd1\x15\xc6`)z\xaa\xe73\x01I\xc7F\xfc\xdf\x14\x02\xd3\xe5-\x86\xa5\xac\xf3'
        b'\xf3y7P-\x07I\x12M\x9d+\x87)\xef0\xd1\xae\r\xcd\x0b\x81\xec\xfc\x1e\t\x8bBM\x17\xfd\x96w\xe6\x90\xd7f\x03\xae\x90\x04N\x17\tj3\xee\xb6\x02/G\x15D\xcc`\xae\xd3\xec\x96$I\xb6&7\x0c'
        b'\xbf\xa3>\xe7a5v\xa1\xa5)K\xea\x03U\x18A\xec\r,\x12\xeb(,\x1ew\x86Vm\x82<\xc9\xd0X\xe3\xdf\x81\x93\xc7/\xd6\xdb\xb0y\xfc\xd6,\x8d\xf6\x991\xa3\xc0Y\x8a\xcb\xa3\x1b,\x80\xe5 R\xab:'
        b'd\x9f\x9a\xc6E\xf8\xc3\x89\xaa\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__'
        b'\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x16<frozen fintech.swift>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x03\x00\x08\x01\x03\x00\x11\x01'
    ))
